
BlacklistPolicyWindow = class(BaseWindow);

-- Initializes a new BlacklistPolicyWindow instance
function BlacklistPolicyWindow:Constructor(viewModel)
	BaseWindow.Constructor(self);
	self.ViewModel = viewModel;

	local bindings = {
		["RefreshButtonClick"] = self.ViewModel.RefreshCommand,
		["ClearButtonClick"] = self.ViewModel.ClearCommand,
		["AutoRefreshChecked"] = self.ViewModel.AutoRefresh,
		["AutoRefreshCheckedChanged"] = function(sender, args)
			self.ViewModel:SetAutoRefresh(sender:IsChecked());
		end,
	};
	
	local content = TemplateLoader.Setup(self, self:GetTemplate(bindings));
	self:SetContent(content);
	self:SetText(self.ViewModel.Title);
	self:FitToContent();
	self:SetMaximumSize(1000, 790);
	self:UpdateStats();
	
	self.ViewModel:OnPropertyChanged("AutoRefresh", function(sender)
		self.AutoRefreshCheckBox:SetChecked(sender.AutoRefresh);
	end);

	self.ViewModel:OnPropertyChanged("BlackList", function()
		self:UpdateStats();
	end);
end

function BlacklistPolicyWindow:Closing(args)
	self.ViewModel:Destroy();
	BaseWindow.Closing(self, args);
end

function BlacklistPolicyWindow:UpdateStats(args)
	self.ItemContainer:Clear();

	for key, entry in pairs(self.ViewModel.BlackList) do
		local bindings = {["Text"] = key, ["Origin"] = "Origin: <rgb=#b9b700>" .. entry.Origin .."</rgb>"};
		local control = TemplateLoader.Setup(self, self:GetItemTemplate(bindings));
		self.ItemContainer:AddControl(control);
	end

	self:Invalidate();
end

function BlacklistPolicyWindow:GetTemplate(bindings)
	return {
		["Type"] = StackPanel,
		["Width"] = 400,
		["Height"] = 300,
		["FitToContent"] = false,
		["Content"] =
		{
			{
				["Type"] = Border,
				["BorderWidth"] = 1,
				["BorderColor"] = Turbine.UI.Color(0.98, 0.4, 0.2, 0.2),
				["Content.DynamicHeight"] = 1,
				["Content"] = 
				{
					{
						["Type"] = Image,
						["ImageMode"] = ImageMode.KeepImage,
						["Background"] = Images.Blacklist,
						["BlendMode"] = Turbine.UI.BlendMode.Multiply,
						["ImageBackColor"] = Turbine.UI.Color(0.98, 0.2, 0.1, 0.1),
						["BackColor"] = Turbine.UI.Color(0.98, 0.2, 0.1, 0.1),
						["Content"] =
						{
							{
								["Type"] = ScrollPanel,
								["Content"] = 
								{
									{
										["Type"] = StackPanel,
										["Name"] = "ItemContainer",
										["Content.Padding"] = 4,
									},
								},
							},
						},
					},
				},
			},
			{
				["Type"] = StackPanel,
				["IsVertical"] = false,
				["Content.PaddingTop"] = 10,
				["Content.DynamicWidth"] = 1,
				["Content"] = 
				{
					{
						["Type"] = Button,
						["Text"] = "Clear",
						["Content.MaxWidth"] = 150,
						["Content.PaddingTop"] = 10,
						["Content.PaddingRight"] = 4,
						["Content.PaddingBottom"] = 4,
						["Content.HorizontalAlignment"] = HorizontalAlignment.Center,
						["Content.DynamicWidth"] = 1,
						["Click"] = bindings["ClearButtonClick"],
					},
					{
						["Type"] = Button,
						["Text"] = "Refresh",
						["Content.MaxWidth"] = 150,
						["Content.PaddingTop"] = 10,
						["Content.PaddingRight"] = 4,
						["Content.PaddingBottom"] = 4,
						["Content.HorizontalAlignment"] = HorizontalAlignment.Center,
						["Content.DynamicWidth"] = 1,
						["Click"] = bindings["RefreshButtonClick"],
					},
				},
			},
			{
				["Type"] = Border,
				["BorderWidth"] = {["Top"] = 1},
				["Content.PaddingTop"] = 10,
				["Content.PaddingBottom"] = 10,
			},
			{
				["Type"] = CheckBox,
				["Name"] = "AutoRefreshCheckBox",
				["Text"] = "Auto Refresh",
				["Checked"] = bindings["AutoRefreshChecked"],
				["CheckedChanged"] = bindings["AutoRefreshCheckedChanged"],
			},
		},
	};
end

function BlacklistPolicyWindow:GetItemTemplate(bindings)
	return {
		["Type"] = StackPanel,
		["Content.Padding"] = 4,
		["Content"] =
		{
			{
				["Type"] = TextBlock,
				["Text"] = bindings["Text"],
				["Content.PaddingTop"] = 10,
			},
			{
				["Type"] = TextBlock,
				["Text"] = bindings["Origin"],
				["Content.PaddingTop"] = 10,
			},
			{
				["Type"] = Border,
				["BorderWidth"] = {["Bottom"] = 1},
				["BorderColor"] = Turbine.UI.Color(0.98, 0.3, 0.2, 0.2),
			},
		},
	};
end